@@ -1,3 +1,4 @@
+# Copyright 2020 Josh Wills. All rights reserved.
 # Copyright Materialize, Inc. and contributors. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,43 +15,24 @@
 # limitations under the License.
 
 from dataclasses import dataclass
-from enum import Enum
 from typing import Optional
 
 from dbt.adapters.postgres import PostgresRelation
-from mashumaro.types import SerializableType
+from dbt.dataclass_schema import StrEnum
 
 
-# Stolen from https://github.com/dbt-labs/dbt/blob/develop/core/dbt/dataclass_schema.py ,
-# which is not importable.
-class StrEnum(str, SerializableType, Enum):
-    def __str__(self):
-        return self.value
-
-    # https://docs.python.org/3.6/library/enum.html#using-automatic-values
-    def _generate_next_value_(name, *_):
-        return name
-
-    def _serialize(self) -> str:
-        return self.value
-
-    @classmethod
-    def _deserialize(cls, value: str):
-        return cls(value)
-
-
-# Override RelationType to add Materialize-specifc materializatiton types:
-#   - source
-#   - index
-#   - sink
 class MaterializeRelationType(StrEnum):
-    Source = "source"
-    View = "view"
-    MaterializedView = "materializedview"
+    # Built-in materialization types.
     Table = "table"
+    View = "view"
+    CTE = "cte"
+    External = "external"
+
+    # Materialize-specific materialization types.
+    Source = "source"
+    MaterializedView = "materializedview"
     Index = "index"
     Sink = "sink"
-    CTE = "cte"
 
 
 @dataclass(frozen=True, eq=False, repr=False)
